import sys
import matplotlib.pyplot as plt
import random

# 白と黒の数および試行回数を可変にするしたシミュレーショングラフ関数を定義
def simulate_stone_draws(n_white, n_black, n_trials,n_xgridinterval,n_ygridinterval):
    # 碁石の設定
    stones = ['white'] * n_white + ['black'] * n_black

    # 結果を記録するリスト
    prob_white_list = []
    prob_black_list = []

    # 各色が選ばれた回数
    count_white = 0
    count_black = 0

    # 試行を繰り返す
    for i in range(1, n_trials + 1):
        chosen_stone = random.choice(stones)
        if chosen_stone == 'white':
            count_white += 1
        else:
            count_black += 1

        # 現在の白と黒の確率を計算
        prob_white = count_white / i
        prob_black = count_black / i

        # 結果をリストに追加
        prob_white_list.append(prob_white)
        prob_black_list.append(prob_black)

    # グラフの描画
    plt.figure(figsize=(10, 6))
    plt.plot(range(1, n_trials + 1), prob_white_list, label='White Probability')
    plt.plot(range(1, n_trials + 1), prob_black_list, label='Black Probability')
    plt.axhline(y=n_white/(n_white + n_black), color='gray', linestyle='--', label=f'Expected White Probability ({n_white}/{n_white + n_black})')
    plt.axhline(y=n_black/(n_white + n_black), color='gray', linestyle='--', label=f'Expected Black Probability ({n_black}/{n_white + n_black})')
 
 # X軸のグリッドを増やす
#デフォルト値は下記
#    plt.xticks(range(0, n_trials + 1, n_trials // 5))  # グリッド間隔を設定
    plt.xticks(range(0, n_trials + 1, n_trials // n_xgridinterval))  # グリッド間隔を設定
    plt.grid(True, which='both', axis='x')  # X軸のグリッドを表示

# Y軸のグリッドを増やす
#デフォルト値は下記
#    plt.yticks([i/5.0 for i in range(0, 6)])  # 0.0から1.0までの目盛りを0.2間隔で設定
    plt.yticks([i/n_ygridinterval for i in range(0, n_ygridinterval+1)])  # 0.0から1.0までの目盛りを指定間隔で設定
    plt.grid(True, which='both', axis='y')  # Y軸のグリッドを表示
 
    plt.xlabel('Number of Trials')
    plt.ylabel('Probability')
    plt.title('Probability of Drawing White and Black Stones')
    plt.legend()
    plt.grid(True)
    plt.show()

#コマンドライン引数から白の数、黒の数、試行回数を取り出す
iwscnt=5
ibscnt=1
iTryCnt=1000
n_xgridinterval=5
n_ygridinterval=5

value=sys.argv
iLen=len(value)
if iLen > 1:
    iwscnt=int(value[1])

if iLen > 2:
   ibscnt=int(value[2])

if iLen > 3:
   iTryCnt=int(value[3])

if iLen > 4:
   n_xgridinterval=int(value[4])

n_ygridinterval=n_xgridinterval
if iLen > 5:
   n_ygridinterval=int(value[5])

if iwscnt < 1:
    iwscnt=1

if ibscnt < 1:
    ibscnt=1

if iTryCnt < 10:
    iTryCnt=10

if n_xgridinterval < 5:
    n_xgridinterval=5

if n_ygridinterval < 5:
    n_ygridinterval=5


# コマンドラインの引数指定でシミュレーションを実行
simulate_stone_draws(iwscnt, ibscnt, iTryCnt, n_xgridinterval, n_ygridinterval)
